/*
 *   Copyright (C) 2019-2020 CERN.
 *   Copyright (C) 2019-2020 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

@navbar_background_image: linear-gradient(20deg, rgba(3, 119, 205, 1), rgba(3, 119, 205, 1) 52.52%, rgba(251, 130, 115, 1));
@navbar_background_color: unset;
@brand-primary: #0377cd;
@versionFirst: rgba(3, 119, 205, 0.28);

@signupColor: @green;
@searchButtonColor: #fb8273;

@coverPageDefaultMargin: 0;

@accessRightOpen: @green;
@accessRightRestricted: @yellow;
@accessRightEmbargoed: @red;
@accessRightClosed: @red;

@footerLightColor: #0377cd;
@footerDarkColor: #0047a8;
@footerTextLightColor: rgba(255, 255, 255, 0.86);
@footerTextDarkColor: #ffffff;

@font-size-base: 14px;
@font-size-small: 12px;
@font-size-tiny: 10px;
@font-size-massive: 36px;

/* Main colors */

@brandColor: @primaryColor;
