{#
    Copyright (C) 2020 CERN.
    Copyright (C) 2020 Northwestern University.

    Invenio RDM Records is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.
#}

<hr class="thin-line"></hr>
<dt>{{_('Citation')}}:</dt>
<dd>
<p><em>Coming soon!</em></p>
<br>
<br>
</dd>
<hr class="thin-line"></hr>
