{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.

  Invenio RDM Records is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
#}

{% set subjects = metadata.get('subjects') %}
{% if subjects %}
<dt><b>{{_('Subjects')}}</b></dt>
<dd class="top-bottom-padded">
  {%- for keyword in metadata.subjects %}
  <span class="label label-keyword">{{ keyword.subject }}</span>
  {%- endfor %}
</dd>
{% endif %}
