# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2021 CERN.
# Copyright (C) 2020-2021 Northwestern University.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Version information for Invenio App RDM.

This file is imported by ``invenio_app_rdm.__init__``,
and parsed by ``setup.py``.
"""

__version__ = '2.0.0.dev1'
